@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -28,6 +28,6 @@ private:
     void importNextServerSieve();
     void importSettings(const QString &directory, const QString &filename);
     QMultiMap<QString, QString> mSieveServerLst;
-    QMap<QString, QString>::const_iterator mSieveServerMapIterator;
+    QMultiMap<QString, QString>::const_iterator mSieveServerMapIterator;
 };
 
