@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,6 +25,4 @@ ImportImapSettingNoFoundPage::ImportImapSettingNoFoundPage(QWidget *parent)
     mainLayout->addWidget(lab);
 }
 
-ImportImapSettingNoFoundPage::~ImportImapSettingNoFoundPage()
-{
-}
+ImportImapSettingNoFoundPage::~ImportImapSettingNoFoundPage() = default;
