@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,6 +31,4 @@ SieveEditorConfigureServerPage::SieveEditorConfigureServerPage(QWidget *parent)
     hbox->addStretch(1);
 }
 
-SieveEditorConfigureServerPage::~SieveEditorConfigureServerPage()
-{
-}
+SieveEditorConfigureServerPage::~SieveEditorConfigureServerPage() = default;
